MultiFileErrorCollector

Trait MultiFileErrorCollector 

pub trait MultiFileErrorCollector: Sealed {
    // Provided methods
    fn add_error(
        self: Pin<&mut Self>,
        filename: &str,
        line: i32,
        column: i32,
        message: &str,
    ) { ... }
    fn add_warning(
        self: Pin<&mut Self>,
        filename: &str,
        line: i32,
        column: i32,
        message: &str,
    ) { ... }
}
If the importer encounters problems while trying to import the proto files, it reports them to a MultiFileErrorCollector.

Provided Methods

fn add_error( self: Pin<&mut Self>, filename: &str, line: i32, column: i32, message: &str, )

Adds an error message to the error collector at the specified position.

Line and column numbers are zero-based. A line number of -1 indicates an error with the entire file (e.g., “not found”).

fn add_warning( self: Pin<&mut Self>, filename: &str, line: i32, column: i32, message: &str, )

Adds a warning to the error collector at the specified position.

See the documentation for add_error for details on the meaning of the line and column parameters.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors